<?php

namespace Drupal\google_calendar_service\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\ContentEntityDeleteForm;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Datetime\TimeInterface;

/**
 * Provides a form for deleting Google Calendar entities.
 *
 * @ingroup google_calendar_service
 */
class CalendarDeleteForm extends ContentEntityDeleteForm {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructor.
   *
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   *   The entity repository service.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   *   The entity type bundle service.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityRepositoryInterface $entity_repository, EntityTypeBundleInfoInterface $entity_type_bundle_info, TimeInterface $time, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($entity_repository, $entity_type_bundle_info, $time);
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getDeletionMessage() {
    /** @var \Drupal\google_calendar_service\Entity\Calendar $entity */
    $entity = $this->getEntity();
    $entityName = $entity->getName();

    // Delete events of the calendar.
    $eventsStorage = $this->entityTypeManager->getStorage('gcs_calendar_event');
    $events = $eventsStorage->getQuery()
      ->accessCheck()
      ->condition(
      'calendar',
      $entity->id()
    )->execute();

    if (!empty($events)) {
      $storage_handler = $this->entityTypeManager->getStorage('gcs_calendar_event');
      $entities = $storage_handler->loadMultiple($events);
      $storage_handler->delete($entities);
    }

    return $this->t('The calendar %title has been deleted.', [
      '%title' => $entityName,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  protected function logDeletionMessage() {
    /** @var \Drupal\google_calendar_service\Entity\Calendar $entity */
    $entity = $this->getEntity();
    $this->logger('content')->notice(
      'The calendar %title has been deleted.',
      ['%title' => $entity->getName()]
    );
  }

}
